==> geopsypack-src-3.3.6.tar.gz: geopsypack-src-3.3.6/gplivemodel/src/DispersionThread.h <==
/***************************************************************************
**
**  This file is part of gplivemodel.
**
**  gplivemodel is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  gplivemodel is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-10-16
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef DISPERSIONTHREAD_H
#define DISPERSIONTHREAD_H

#include <QGpCoreWave.h>

#include "Seismic1DThread.h"

class DispersionThread : public Seismic1DThread
{
  Q_OBJECT
public:
  DispersionThread(QObject * parent=nullptr);
  DispersionThread(const DispersionThread& o);
  ~DispersionThread();

  virtual ResultsThread * clone() const {return new DispersionThread(*this);}

  virtual void initResultsGraphs(GraphicSheet * sheet);
  virtual void initResultsGraphs(const ResultsThread& o) {CurvesThread::initResultsGraphs(o);}
  virtual bool setParameters(int& argc, char ** argv);
private:
  virtual void run(GeophysicalModel * m);

  int _nRayleigh, _nLove;
  Mode::Slowness _slowness;
};

#endif // DISPERSIONTHREAD_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/gplivemodel/src/DispersionThread.h <==
/***************************************************************************
**
**  This file is part of gplivemodel.
**
**  gplivemodel is free software: you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation, either version 3 of the License, or
**  (at your option) any later version.
**
**  gplivemodel is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with Foobar.  If not, see <http://www.gnu.org/licenses/>
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2008-10-16
**  Copyright: 2008-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef DISPERSIONTHREAD_H
#define DISPERSIONTHREAD_H

#include <QGpCoreWave.h>

#include "Seismic1DThread.h"

class DispersionThread : public Seismic1DThread
{
  Q_OBJECT
public:
  DispersionThread(QObject * parent=nullptr);
  DispersionThread(const DispersionThread& o);
  ~DispersionThread();

  ResultsThread * clone() const {return new DispersionThread(*this);}

  void initResultsGraphs(GraphicSheet * sheet);
  void initResultsGraphs(const ResultsThread& o) {CurvesThread::initResultsGraphs(o);}
  bool setParameters(int& argc, char ** argv);
private:
  virtual void run(GeophysicalModel * m);

  int _nRayleigh, _nLove;
  Mode::Slowness _slowness;
};

#endif // DISPERSIONTHREAD_H
